import { PolicyStatement } from 'aws-cdk-lib/aws-iam';
import { CodePipeline } from 'aws-cdk-lib/pipelines';
import { Construct } from 'constructs';
import { TrackedConstruct, SparkImage } from '../../utils';
import { ApplicationStackFactory } from '../../utils/application-stack-factory';
/**
 * The account information for deploying the Spark Application stack.
 */
export interface AccountInfo {
    /**
     * The account ID to deploy the Spark Application stack
     */
    readonly accountId: string;
    /**
     * The region to deploy the Spark Application stack
     */
    readonly region: string;
}
/**
* Properties for SparkEmrCICDPipeline class.
*/
export interface SparkEmrCICDPipelineProps {
    /**
    * The name of the Spark application to be deployed.
    */
    readonly sparkApplicationName: string;
    /**
     * The application Stack to deploy in the different CDK Pipelines Stages
     */
    readonly applicationStackFactory: ApplicationStackFactory;
    /**
     * The path to the folder that contains the CDK Application
     * @default - The root of the repository
     */
    readonly cdkApplicationPath?: string;
    /**
     * The path to the folder that contains the Spark Application
     * @default - The root of the repository
     */
    readonly sparkApplicationPath?: string;
    /**
     * The EMR Spark image to use to run the unit tests
     * @default - EMR v6.12 is used
     */
    readonly sparkImage?: SparkImage;
    /**
     * The path to the Shell script that contains integration tests
     * @default - No integration tests are run
     */
    readonly integTestScript?: string;
    /**
     * The environment variables to create from the Application Stack and to pass to the integration tests.
     * This is used to interact with resources created by the Application Stack from within the integration tests script.
     * Key is the name of the environment variable to create. Value is generally a CfnOutput name from the Application Stack.
     * @default - No environment variables
     */
    readonly integTestEnv?: Record<string, string>;
    /**
     * The IAM policy statements to add permissions for running the integration tests.
     * @default - No permissions
     */
    readonly integTestPermissions?: PolicyStatement[];
}
/**
* A CICD Pipeline that tests and deploys a Spark application in cross-account environments using CDK Pipelines.
*
* @example
* const stack = new Stack();
*
* interface MyApplicationStackProps extends StackProps {
*   readonly stage: CICDStage;
* }
*
* class MyApplicationStack extends Stack {
*   constructor(scope: Stack, props?: MyApplicationStackProps) {
*     super(scope, 'MyApplicationStack');
**     const bucket = new Bucket(this, 'TestBucket', {
*       autoDeleteObjects: true,
*       removalPolicy: RemovalPolicy.DESTROY,
*     });
*     new CfnOutput(this, 'BucketName', { value: bucket.bucketName });
*   }
* }
*
* class MyStackFactory implements ApplicationStackFactory {
*   createStack(scope: Stack, stage: CICDStage): Stack {
*     return new MyApplicationStack(scope, { stage });
*   }
* }
*
* new SparkCICDPipeline(stack, 'TestConstruct', {
*   sparkApplicationName: 'test',
*   applicationStackFactory: new MyStackFactory(),
*   cdkApplicationPath: 'cdk/',
*   sparkApplicationPath: 'spark/',
*   sparkImage: SparkImage.EMR_SERVERLESS_6_10,
*   integTestScript: 'cdk/integ-test.sh',
*   integTestEnv: {
*     TEST_BUCKET: 'BucketName',
*   },
* });
*/
export declare class SparkEmrCICDPipeline extends TrackedConstruct {
    /**
     * Extract the path and the script name from a script path
     * @param path the script path
     * @return [path, scriptName]
     */
    private static extractPath;
    /**
     * Build the install commands for the CodeBuild step based on the runtime
     * @param cdkPath the path of the CDK application
     * @param sparkPath the path of the Spark application
     * @return installCommands
     */
    private static synthCommands;
    /**
     * The CodePipeline created as part of the Spark CICD Pipeline
     */
    readonly pipeline: CodePipeline;
    /**
     * Construct a new instance of the SparkCICDPipeline class.
     * @param {Construct} scope the Scope of the CDK Construct
     * @param {string} id the ID of the CDK Construct
     * @param {SparkEmrCICDPipelineProps} props the SparkCICDPipelineProps properties
     */
    constructor(scope: Construct, id: string, props: SparkEmrCICDPipelineProps);
    /**
     * Extract PROD and STAGING account IDs and regions from the CDK context
     */
    private getAccountFromContext;
}
